@@ -7,7 +7,8 @@ describe 'sahara' do
 
   let :params do
     {
-      :admin_password => 'secrete'
+      :admin_password => 'secrete',
+      :purge_config   => false,
     }
   end
 
@@ -18,6 +19,12 @@ describe 'sahara' do
     it { is_expected.to contain_class('sahara::policy') }
     it { is_expected.to contain_class('mysql::bindings::python') }
     it { is_expected.to contain_exec('sahara-dbmanage') }
+
+    it 'passes purge to resource' do
+      is_expected.to contain_resources('sahara_config').with({
+        :purge => false
+      })
+    end
   end
 
   shared_examples_for 'sahara config' do
@@ -31,10 +38,13 @@ describe 'sahara' do
       it { is_expected.to contain_sahara_config('keystone_authtoken/admin_user').with_value('sahara') }
       it { is_expected.to contain_sahara_config('keystone_authtoken/admin_tenant_name').with_value('services') }
       it { is_expected.to contain_sahara_config('keystone_authtoken/admin_password').with_value('secrete').with_secret(true) }
+      it { is_expected.to contain_sahara_config('keystone_authtoken/memcached_servers').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_sahara_config('DEFAULT/plugins').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_sahara_config('oslo_messaging_rabbit/kombu_reconnect_delay').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_sahara_config('oslo_messaging_rabbit/kombu_compression').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_sahara_config('oslo_messaging_rabbit/kombu_failover_strategy').with_value('<SERVICE DEFAULT>') }
+      it { is_expected.to contain_sahara_config('DEFAULT/transport_url').with_value('<SERVICE DEFAULT>') }
+      it { is_expected.to contain_sahara_config('DEFAULT/control_exchange').with_value('<SERVICE DEFAULT>') }
     end
 
     context 'with passing params' do
@@ -47,7 +57,10 @@ describe 'sahara' do
         :admin_user            => 'sahara-user',
         :admin_tenant_name     => 'sahara-tenant',
         :admin_password        => 'new_password',
+        :memcached_servers     => '1.1.1.1:11211',
         :plugins               => ['plugin1', 'plugin2'],
+        :default_transport_url => 'rabbit://guest2:pass@localhost2:5673',
+        :control_exchange      => 'openstack',
       }
       end
 
@@ -59,7 +72,10 @@ describe 'sahara' do
       it { is_expected.to contain_sahara_config('keystone_authtoken/admin_user').with_value('sahara-user') }
       it { is_expected.to contain_sahara_config('keystone_authtoken/admin_tenant_name').with_value('sahara-tenant') }
       it { is_expected.to contain_sahara_config('keystone_authtoken/admin_password').with_value('new_password').with_secret(true) }
+      it { is_expected.to contain_sahara_config('keystone_authtoken/memcached_servers').with_value('1.1.1.1:11211') }
       it { is_expected.to contain_sahara_config('DEFAULT/plugins').with_value('plugin1,plugin2') }
+      it { is_expected.to contain_sahara_config('DEFAULT/transport_url').with_value('rabbit://guest2:pass@localhost2:5673') }
+      it { is_expected.to contain_sahara_config('DEFAULT/control_exchange').with_value('openstack') }
     end
 
   end
@@ -85,15 +101,15 @@ describe 'sahara' do
       context 'when passing params' do
         before do
           params.merge!({
-            :rabbit_password         => 'pass',
-            :rabbit_userid           => 'guest2',
-            :rabbit_host             => 'localhost2',
-            :rabbit_port             => '5673',
-            :rabbit_ha_queues        => 'true',
-            :amqp_durable_queues     => 'true',
-            :kombu_reconnect_delay   => '1.0',
-            :kombu_compression       => 'gzip',
-            :kombu_failover_strategy => 'round-robin',
+            :rabbit_password            => 'pass',
+            :rabbit_userid              => 'guest2',
+            :rabbit_host                => 'localhost2',
+            :rabbit_port                => '5673',
+            :rabbit_ha_queues           => 'true',
+            :amqp_durable_queues        => 'true',
+            :kombu_reconnect_delay      => '1.0',
+            :kombu_compression          => 'gzip',
+            :kombu_failover_strategy    => 'round-robin',
           })
         end
 
